SpecViz: Interactive Spectral Analysis
######################################

.. DANGER::

      Please note that this version of SpecViz is **no longer being actively supported
      or maintained**. The functionality of SpecViz is now available and being actively
      developed as part of `Jdaviz <https://github.com/spacetelescope/jdaviz>`_.

If you must use legacy SpecViz, please try v0.7.1 in Python 3.6. For legacy
SpecViz, see https://specviz.readthedocs.io/en/0.7.0/ .

If you would like to fork https://github.com/spacetelescope/specviz/
and continue developing in your own, we suggest you start from commit
``b8bcd495e5b43dc2b90f7bf2d5bad2d27c6990aa``.
